==> ev_framework-3.0.8.tar.gz: lib/_FrameWork/Ev/_Form_Item.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_text extends StatefulWidget {
  vForm form;
  var skey;
  var value;
  var hinttext;
  var maxlength;
  var keyboard_type;
  TextEditingController controller;
  var label_text;
  var readonly;
  var textcolor;

  var max_line;
  var min_line;
  var ispassword;
  var icon;
  var onChange;
  var text_align;

  $$Form_text(Key key,this.skey,this.form,this.value,this.controller,
      { this.label_text,this.hinttext,this.maxlength,this.keyboard_type,
        this.max_line=1,this.min_line=1,this.ispassword = false,this.readonly =false,this.textcolor,this.icon,this.onChange,this.text_align}):super(key:key);

  @override
  _Form_textState createState() => _Form_textState();
}

class _Form_textState extends State<$$Form_text> {
  var value;
  var password_on;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    value = widget.value;
    form = widget.form;
    password_on = widget.ispassword;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
     Widget c =  TextField(
       onChanged: widget.onChange,
       readOnly: widget.readonly,
       textAlign: widget.text_align ?? form.$$_Text_Align,
       minLines: widget.min_line,
       maxLines: widget.max_line,
       style: TextStyle(
           fontSize: form.$$_Input_Size, color: widget.textcolor ?? form.$$_Input_Color),
       obscureText: password_on,

       decoration: new InputDecoration(
         border: InputBorder.none,
         hintText: vSystem.lang_text(widget.hinttext),
         hintStyle: TextStyle(fontSize: 13, color: Colors.grey.withOpacity(0.7)),
         contentPadding: EdgeInsets.all(8),
         counterText: "",
         isDense: true,

       ),
       controller: widget.controller,
       maxLength: widget.maxlength,
       keyboardType: widget.keyboard_type,
     );

     if(widget.icon != null) {
       c = Row(children: [
         widget.icon,
         SizedBox(width: 5,),
         Expanded(child: c,)

       ],);
     }

     if (widget.ispassword) {
       c = Row(children: [
         Expanded(child: c),
         SizedBox(width: 5,),
         Material( color: Colors.transparent,
           child : InkWell(
             child : Icon(
               Icons.remove_red_eye,color:  (!password_on) ? form.$$_Input_Color : Colors.grey.withOpacity(0.5),
               size: 26,
             ),
             onTap : () { setState(() {
               password_on = password_on ? false : true;
             });
             },
           ),
         ),

         SizedBox(width: 5,),
       ],);
     }

    if(form.$$_Border_type ==0)
      { return Material(child:c,color: Colors.transparent,); }

    if (form.$$_Border_type == 1) {
      return Material(child: form_type1(c),color: Colors.transparent,);
    }
    else {
      return Material(child: form_type2(c),color: Colors.transparent,);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";

    return Container(
      padding: form.$$_Margin,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          (form.$$_Lable_ratio > 0) ?
          Padding(
            padding: form.$$_Padding,
            child: Row(
                children: <Widget>[
                  Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                  SizedBox(width: 10),
                  Expanded(flex: 100,child: child)
                ]),
          ):

          (widget.label_text=="") ? Padding(padding: form.$$_Padding,child:child) :
          Padding(
            padding: form.$$_Padding,
            child: Row(
                children: <Widget>[
                  vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                  SizedBox(width: 10),
                  Expanded(child: child)
                ]),
          ),
          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";
    var decoration = BoxDecoration(
      color: form.$$_Bg_Color,
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
     padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child:
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,
                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }
}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/Ev/_Form_Item.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_text extends StatefulWidget {
  vForm form;
  var skey;
  var value;
  var hinttext;
  var maxlength;
  var keyboard_type;
  TextEditingController controller;
  var label_text;
  var readonly;
  var textcolor;

  var max_line;
  var min_line;
  var ispassword;
  var icon;
  var onChange;
  var text_align;
  var onSubmit;

  $$Form_text(Key key,this.skey,this.form,this.value,this.controller,
      { this.label_text,this.hinttext,this.maxlength,this.keyboard_type,
        this.max_line=1,this.min_line=1,this.ispassword = false,this.readonly =false,this.textcolor,this.icon,this.onChange,this.text_align,this.onSubmit}):super(key:key);

  @override
  _Form_textState createState() => _Form_textState();
}

class _Form_textState extends State<$$Form_text> {
  var value;
  var password_on;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    value = widget.value;
    form = widget.form;
    password_on = widget.ispassword;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
     Widget c =  TextField(
       onChanged: widget.onChange,
       readOnly: widget.readonly,
       textAlign: widget.text_align ?? form.$$_Text_Align,
       minLines: widget.min_line,
       maxLines: widget.max_line,
       onSubmitted: widget.onSubmit,
       style: TextStyle(
           fontSize: form.$$_Input_Size, color: widget.textcolor ?? form.$$_Input_Color),
       obscureText: password_on,

       decoration: new InputDecoration(
         border: InputBorder.none,
         hintText: vSystem.lang_text(widget.hinttext),
         hintStyle: TextStyle(fontSize: 13, color: Colors.grey.withOpacity(0.7)),
         contentPadding: EdgeInsets.all(8),
         counterText: "",
         isDense: true,

       ),
       controller: widget.controller,
       maxLength: widget.maxlength,
       keyboardType: widget.keyboard_type,
     );

     if(widget.icon != null) {
       c = Row(children: [
         widget.icon,
         SizedBox(width: 5,),
         Expanded(child: c,)

       ],);
     }

     if (widget.ispassword) {
       c = Row(children: [
         Expanded(child: c),
         SizedBox(width: 5,),
         Material( color: Colors.transparent,
           child : InkWell(
             child : Icon(
               Icons.remove_red_eye,color:  (!password_on) ? form.$$_Input_Color : Colors.grey.withOpacity(0.5),
               size: 26,
             ),
             onTap : () { setState(() {
               password_on = password_on ? false : true;
             });
             },
           ),
         ),

         SizedBox(width: 5,),
       ],);
     }

    if(form.$$_Border_type ==0)
      { return Material(child:c,color: Colors.transparent,); }

    if (form.$$_Border_type == 1) {
      return Material(child: form_type1(c),color: Colors.transparent,);
    }
    else {
      return Material(child: form_type2(c),color: Colors.transparent,);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";

    return Container(
      padding: form.$$_Margin,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          (form.$$_Lable_ratio > 0) ?
          Padding(
            padding: form.$$_Padding,
            child: Row(
                children: <Widget>[
                  Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                  SizedBox(width: 10),
                  Expanded(flex: 100,child: child)
                ]),
          ):

          (widget.label_text=="") ? Padding(padding: form.$$_Padding,child:child) :
          Padding(
            padding: form.$$_Padding,
            child: Row(
                children: <Widget>[
                  vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                  SizedBox(width: 10),
                  Expanded(child: child)
                ]),
          ),
          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";
    var decoration = BoxDecoration(
      color: form.$$_Bg_Color,
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
     padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child:
                    Padding(
                      padding: const EdgeInsets.only(bottom: 8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,
                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }
}
